@@ -23,11 +23,12 @@ from airflow.providers.databricks.hooks.databricks import RunState
 
 def normalise_json_content(content, json_path: str = "json") -> str | bool | list | dict:
     """
-    Normalize content or all values of content if it is a dict to a string. The
-    function will throw if content contains non-string or non-numeric non-boolean types.
-    The reason why we have this function is because the ``self.json`` field must be a
-    dict with only string values. This is because ``render_template`` will fail
-    for numerical values.
+    Normalize content or all values of content if it is a dict to a string.
+
+    The function will throw if content contains non-string or non-numeric non-boolean
+    types. The reason why we have this function is because the ``self.json`` field
+    must be a dict with only string values. This is because ``render_template`` will
+    fail for numerical values.
 
     The only one exception is when we have boolean values, they can not be converted
     to string type because databricks does not understand 'True' or 'False' values.
@@ -35,19 +36,13 @@ def normalise_json_content(content, json_path: str = "json") -> str | bool | lis
     normalise = normalise_json_content
     if isinstance(content, (str, bool)):
         return content
-    elif isinstance(
-        content,
-        (
-            int,
-            float,
-        ),
-    ):
+    elif isinstance(content, (int, float)):
         # Databricks can tolerate either numeric or string types in the API backend.
         return str(content)
     elif isinstance(content, (list, tuple)):
         return [normalise(e, f"{json_path}[{i}]") for i, e in enumerate(content)]
     elif isinstance(content, dict):
-        return {k: normalise(v, f"{json_path}[{k}]") for k, v in list(content.items())}
+        return {k: normalise(v, f"{json_path}[{k}]") for k, v in content.items()}
     else:
         param_type = type(content)
         msg = f"Type {param_type} used for parameter {json_path} is not a number or a string"
@@ -56,8 +51,9 @@ def normalise_json_content(content, json_path: str = "json") -> str | bool | lis
 
 def validate_trigger_event(event: dict):
     """
-    Validates correctness of the event
-    received from :class:`~airflow.providers.databricks.triggers.databricks.DatabricksExecutionTrigger`.
+    Validates correctness of the event received from DatabricksExecutionTrigger.
+
+    See: :class:`~airflow.providers.databricks.triggers.databricks.DatabricksExecutionTrigger`.
     """
     keys_to_check = ["run_id", "run_page_url", "run_state"]
     for key in keys_to_check:
